#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 with-location
version:              0.1.0
visibility:           public
id:                   with-location-0.1.0-2XbnI7s91YUEUqZoPEDtLh
key:                  with-location-0.1.0-2XbnI7s91YUEUqZoPEDtLh
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/with-location#readme
synopsis:
    Use ImplicitParams-based source locations in a backward compatible way

category:             Data
abi:                  3726cbce192bd334ad80d2a75d7133de
exposed:              True
exposed-modules:      Data.WithLocation
import-dirs:          /usr/lib/ghc-9.6.6/site-local/with-location-0.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/with-location-0.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/with-location-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-with-location
hs-libraries:         HSwith-location-0.1.0-2XbnI7s91YUEUqZoPEDtLh
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-with-location/html/with-location.haddock

haddock-html:         /usr/share/doc/haskell-with-location/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

